
package presentacion;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;

public class Opcion3 extends JPanel {
 
      private Componentes componentes;
      
    public Opcion3(Componentes componentes) {
        this.componentes = componentes;
        ubicarComponentes();
    }
     
    private void ubicarComponentes() {

        setLayout(null);        
                   // CONFIGURACIÓN JButton 
        componentes.setjButtonOpcion3(new JButton("Contar"));
        componentes.getjButtonOpcion3().setBounds(255, 220, 100, 40);  
        componentes.getjButtonOpcion3().setActionCommand("botonOpcion3");
        componentes.getjButtonOpcion3().addActionListener(componentes.getGestorEventos());   // REGISTRO DE ESCUCHA DE EVENTO DE BOTON
        add(componentes.getjButtonOpcion3());   
                   // CONFIGURACIÓN JLabel visualización contador parcial
        componentes.setjLabelParcialOpcion3(new JLabel("Pulsaciones botón opción 3:     "+componentes.getContadorOpcion3()));
        componentes.getjLabelParcialOpcion3().setBounds(100, 100, 400, 20);
        add(componentes.getjLabelParcialOpcion3()); 
                   // CONFIGURACIÓN JLabel visualización contador global
        componentes.setjLabelGlobalOpcion3(new JLabel("Pulsaciones acumuladas de los botones de todas las opciones:     "+componentes.getContadorGlobal()));
        componentes.getjLabelGlobalOpcion3().setBounds(100, 150, 400, 20);
        add(componentes.getjLabelGlobalOpcion3());                         
    }       
    
    public void iniciarPantalla() {
        componentes.setContadorOpcion3(0);
        componentes.getjLabelParcialOpcion3().setText("Pulsaciones botón opción 3:     "+componentes.getContadorOpcion3());
        componentes.getjLabelGlobalOpcion3().setText("Pulsaciones acumuladas de los botones de todas las opciones:     "+componentes.getContadorGlobal());        
    }    
}
